@@ -10,17 +10,16 @@ from tornado.httpclient import AsyncHTTPClient
 from tornado.web import url
 from torndb import Connection
 
-from cyclops.handlers.router import RouterHandler, CountHandler
+from cyclops.handlers.router import GetRouterHandler, PostRouterHandler, CountHandler
 from cyclops.handlers.healthcheck import HealthCheckHandler
 from cyclops.tasks import ProjectsUpdateTask, SendToSentryTask
 
 
 def get_cache(module_name):
-    if '.' in module_name:
-        modules = module_name.split('.')
-    else:
-        modules = [module_name]
+    if '.' not in module_name:
+        return __import__(module_name)
 
+    modules = module_name.split('.')
     return reduce(getattr, modules[1:], __import__(".".join(modules[:-1])))
 
 
@@ -29,8 +28,8 @@ def configure_app(self, config=None, log_level='INFO', debug=False, main_loop=No
     self.main_loop = main_loop
 
     handlers = [
-        url(r'/api/(?P<project_id>\d+)/store/', RouterHandler, name="router"),
-        url(r'/api/store/', RouterHandler, name="router_post"),
+        url(r'/api/(?P<project_id>\d+)/store/', GetRouterHandler, name="router"),
+        url(r'/api/store/', PostRouterHandler, name="router_post"),
         url(r'/count', CountHandler, name="count"),
         url(r'/healthcheck(?:/|\.html)?', HealthCheckHandler, name="healthcheck"),
     ]
